@@ -10,7 +10,10 @@ use Path::Tiny 0.089;
 use Scalar::Util qw(openhandle);
 use Text::Gitignore qw(build_gitignore_matcher);
 
-our $VERSION = '0.53'; # VERSION
+our $VERSION = '0.54'; # VERSION
+
+my $RE_PATTERN  = qr/.+?(?<!\\)/;
+my $RE_OWNER    = qr/(?:\@+"[^"]*")|(?:\H+)/;
 
 sub _croak { require Carp; Carp::croak(@_); }
 sub _usage { _croak("Usage: @_\n") }
@@ -26,11 +29,10 @@ sub parse {
     my $self  = shift;
     my $input = shift or _usage(q{$codeowners->parse($input)});
 
-    return $self->parse_from_array($input, @_) if @_;
-    return $self->parse_from_array($input)  if ref($input) eq 'ARRAY';
-    return $self->parse_from_string($input) if ref($input) eq 'SCALAR';
-    return $self->parse_from_fh($input)     if openhandle($input);
-    return $self->parse_from_filepath($input);
+    return $self->parse_from_array($input, @_)  if ref($input) eq 'ARRAY';
+    return $self->parse_from_string($input, @_) if ref($input) eq 'SCALAR';
+    return $self->parse_from_fh($input, @_)     if openhandle($input);
+    return $self->parse_from_filepath($input, @_);
 }
 
 
@@ -40,13 +42,14 @@ sub parse_from_filepath {
 
     $self = bless({}, $self) if !ref($self);
 
-    return $self->parse_from_fh(path($path)->openr_utf8);
+    return $self->parse_from_fh(path($path)->openr_utf8, @_);
 }
 
 
 sub parse_from_fh {
     my $self = shift;
     my $fh   = shift or _usage(q{$codeowners->parse_from_fh($fh)});
+    my %opts = @_;
 
     $self = bless({}, $self) if !ref($self);
 
@@ -54,6 +57,7 @@ sub parse_from_fh {
 
     my $parse_unowned;
     my %unowned;
+    my %aliases;
     my $current_project;
 
     while (my $line = <$fh>) {
@@ -77,9 +81,18 @@ sub parse_from_fh {
         elsif ($line =~ /^\h*$/) {
             # blank line
         }
-        elsif ($line =~ /^\h*(.+?)(?<!\\)\h+(.+)/) {
+        elsif ($opts{aliases} && $line =~ /^\h*\@($RE_OWNER)\h+(.+)/) {
+            my $alias   = $1;
+            my @owners  = $2 =~ /($RE_OWNER)/g;
+            $aliases{$alias} = \@owners;
+            $lines[$lineno] = {
+                alias   => $alias,
+                owners  => \@owners,
+            };
+        }
+        elsif ($line =~ /^\h*($RE_PATTERN)\h+(.+)/) {
             my $pattern = $1;
-            my @owners  = $2 =~ /( (?:\@+"[^"]*") | (?:\H+) )/gx;
+            my @owners  = $2 =~ /($RE_OWNER)/g;
             $lines[$lineno] = {
                 pattern => $pattern,
                 owners  => \@owners,
@@ -103,6 +116,7 @@ sub parse_from_fh {
 
     $self->{lines} = \@lines;
     $self->{unowned} = \%unowned;
+    $self->{aliases} = \%aliases;
 
     return $self;
 }
@@ -114,9 +128,8 @@ sub parse_from_array {
 
     $self = bless({}, $self) if !ref($self);
 
-    $arr = [$arr, @_] if @_;
     my $str = join("\n", @$arr);
-    return $self->parse_from_string(\$str);
+    return $self->parse_from_string(\$str, @_);
 }
 
 
@@ -129,7 +142,7 @@ sub parse_from_string {
     my $ref = ref($str) eq 'SCALAR' ? $str : \$str;
     open(my $fh, '<:encoding(UTF-8)', $ref) or die "open failed: $!";
 
-    return $self->parse_from_fh($fh);
+    return $self->parse_from_fh($fh, @_);
 }
 
 
@@ -175,6 +188,10 @@ sub write_to_array {
             my $owners = join(' ', @{$line->{owners}});
             push @format, "$pattern  $owners";
         }
+        elsif (my $alias = $line->{alias}) {
+            my $owners = join(' ', @{$line->{owners}});
+            push @format, "\@$alias  $owners";
+        }
         else {
             push @format, '';
         }
@@ -199,6 +216,17 @@ sub write_to_array {
 sub match {
     my $self     = shift;
     my $filepath = shift or _usage(q{$codeowners->match($filepath)});
+    my %opts     = @_;
+
+    my $expand = $opts{expand} ? do {
+        my $aliases = $self->aliases;
+        sub {
+            my $owner = shift;
+            my $alias = $aliases->{$owner};
+            return @$alias if $alias;
+            return $owner;
+        };
+    } : sub { shift };  # noop
 
     my $lines = $self->{match_lines} ||= [reverse grep { ($_ || {})->{pattern} } @{$self->_lines}];
 
@@ -206,7 +234,7 @@ sub match {
         my $matcher = $line->{matcher} ||= build_gitignore_matcher([$line->{pattern}]);
         return {    # deep copy
             pattern => $line->{pattern},
-            owners  => [@{$line->{owners} || []}],
+            owners  => [map { $expand->($_) } @{$line->{owners} || []}],
             $line->{project} ? (project => $line->{project}) : (),
         } if $matcher->($filepath);
     }
@@ -254,6 +282,21 @@ sub patterns {
 }
 
 
+sub aliases {
+    my $self = shift;
+
+    return $self->{aliases} if $self->{aliases};
+
+    my %aliases;
+    for my $line (@{$self->_lines}) {
+        next if !defined $line->{alias};
+        $aliases{$line->{alias}} = [@{$line->{owners}}];
+    }
+
+    return $self->{aliases} = \%aliases;
+}
+
+
 sub projects {
     my $self  = shift;
 
@@ -415,9 +458,11 @@ sub _clear {
     delete $self->{match_lines};
     delete $self->{owners};
     delete $self->{patterns};
+    delete $self->{aliases};
     delete $self->{projects};
 }
 
+
 1;
 
 __END__
@@ -432,7 +477,13 @@ File::Codeowners - Read and write CODEOWNERS files
 
 =head1 VERSION
 
-version 0.53
+version 0.54
+
+=head1 DESCRIPTION
+
+This module parses and generates F<CODEOWNERS> files.
+
+See L<CODEOWNERS syntax|https://docs.github.com/en/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-code-owners#codeowners-syntax>.
 
 =head1 METHODS
 
@@ -444,37 +495,47 @@ Construct a new L<File::Codeowners>.
 
 =head2 parse
 
-    $codeowners = File::Codeowners->parse('path/to/CODEOWNERS');
-    $codeowners = File::Codeowners->parse($filehandle);
-    $codeowners = File::Codeowners->parse(\@lines);
-    $codeowners = File::Codeowners->parse(\$string);
+    $codeowners = File::Codeowners->parse($filepath, @options);
+    $codeowners = File::Codeowners->parse(*IO, @options);
+    $codeowners = File::Codeowners->parse(\@lines, @options);
+    $codeowners = File::Codeowners->parse(\$string, @options);
 
 Parse a F<CODEOWNERS> file.
 
 This is a shortcut for the C<parse_from_*> methods.
 
+Possible options:
+
+=over 4
+
+=item *
+
+C<aliases> - Parse lines that begin with "@" as aliases (default: false)
+
+=back
+
 =head2 parse_from_filepath
 
-    $codeowners = File::Codeowners->parse_from_filepath('path/to/CODEOWNERS');
+    $codeowners = File::Codeowners->parse_from_filepath($filepath, @options);
 
 Parse a F<CODEOWNERS> file from the filesystem.
 
 =head2 parse_from_fh
 
-    $codeowners = File::Codeowners->parse_from_fh($filehandle);
+    $codeowners = File::Codeowners->parse_from_fh(*IO, @options);
 
 Parse a F<CODEOWNERS> file from an open filehandle.
 
 =head2 parse_from_array
 
-    $codeowners = File::Codeowners->parse_from_array(\@lines);
+    $codeowners = File::Codeowners->parse_from_array(\@lines, @options);
 
 Parse a F<CODEOWNERS> file stored as lines in an array.
 
 =head2 parse_from_string
 
-    $codeowners = File::Codeowners->parse_from_string(\$string);
-    $codeowners = File::Codeowners->parse_from_string($string);
+    $codeowners = File::Codeowners->parse_from_string(\$string, @options);
+    $codeowners = File::Codeowners->parse_from_string($string, @options);
 
 Parse a F<CODEOWNERS> file stored as a string. String should be UTF-8 encoded.
 
@@ -492,19 +553,19 @@ Format the file contents and write to a filehandle.
 
 =head2 write_to_string
 
-    $scalarref = $codeowners->write_to_string;
+    \$string = $codeowners->write_to_string;
 
 Format the file contents and return a reference to a formatted string.
 
 =head2 write_to_array
 
-    $lines = $codeowners->write_to_array;
+    \@lines = $codeowners->write_to_array;
 
 Format the file contents as an arrayref of lines.
 
 =head2 match
 
-    $owners = $codeowners->match($filepath);
+    \%match = $codeowners->match($filepath, %options);
 
 Match the given filepath against the available patterns and return just the
 owners for the matching pattern. Patterns are checked in the reverse order
@@ -512,6 +573,16 @@ they were defined in the file.
 
 Returns C<undef> if no patterns match.
 
+Possible options:
+
+=over 4
+
+=item *
+
+C<expand> - Expand group aliases defined in the F<CODEOWNERS> file.
+
+=back
+
 =head2 owners
 
     $owners = $codeowners->owners; # get all defined owners
@@ -529,9 +600,15 @@ defined in the file.
 
 Get an arrayref of all patterns defined.
 
+=head2 aliases
+
+    \%aliases = $codeowners->aliases;
+
+Get a hashref of all aliases defined.
+
 =head2 projects
 
-    $projects = $codeowners->projects;
+    \@projects = $codeowners->projects;
 
 Get an arrayref of all projects defined.
 
@@ -586,7 +663,7 @@ Prepend a new line.
 
 =head2 unowned
 
-    $filepaths = $codeowners->unowned;
+    \@filepaths = $codeowners->unowned;
 
 Get the list of filepaths in the "unowned" section.
 
